@@ -305,6 +305,7 @@ static int
 meta_image (GnomePrintContext *pc, const gdouble *affine, const guchar *px, gint w, gint h, gint rowstride, gint ch)
 {
 	int i, y;
+	GnomePrintMeta *meta;
 
 	gpm_encode_int (pc, GNOME_META_IMAGE);
 	for (i = 0; i < 6; i++) gpm_encode_double (pc, affine[i]);
@@ -312,6 +313,12 @@ meta_image (GnomePrintContext *pc, const gdouble *affine, const guchar *px, gint
 	gpm_encode_int (pc, w);
 	gpm_encode_int (pc, ch);
 
+	meta = (GnomePrintMeta *)pc;
+	if (!GPM_ENSURE_SPACE (meta, w * ch * h)) {
+		g_warning ("file %s: line %d: Cannot grow metafile buffer (%d bytes)", __FILE__, __LINE__, w * ch * h);
+		return GNOME_PRINT_ERROR_UNKNOWN;
+	}
+
 	for (y = 0; y < h; y++){
 		gpm_encode_block (pc, px, w * ch);
 		px += rowstride;
