@@ -246,7 +246,7 @@ gpa_option_create_key (GPAOption *option, GPANode *parent)
 	if (option->type == GPA_OPTION_TYPE_LIST) {
 		child = gpa_option_get_child_by_id (option, option->value);
 		if (child != NULL)
-		child = child->children;
+			child = child->children;
 	} else {
 		child = GPA_NODE (option)->children;
 	}
@@ -386,12 +386,11 @@ gpa_option_new_from_tree (xmlNodePtr tree, GPANode *parent)
 new_from_tree_option_loaded:
 	locked = xmlGetProp (tree, "Locked");
 	
-	if (option)
-		if (locked && !strcmp (locked, "true")) {
-			GPA_NODE_SET_FLAGS (option, NODE_FLAG_LOCKED);
-		} else {
-			GPA_NODE_UNSET_FLAGS (option, NODE_FLAG_LOCKED);
-		}		
+	if (locked && !strcmp (locked, "true")) {
+		GPA_NODE_SET_FLAGS (option, NODE_FLAG_LOCKED);
+	} else {
+		GPA_NODE_UNSET_FLAGS (option, NODE_FLAG_LOCKED);
+	}		
 	
 new_from_tree_done:
 	my_xmlFree (locked);
